==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/member_links_self_iri_template_mapping.dart <==
part of keyclic_sdk_api.api;

class MemberLinksSelfIriTemplateMapping {
  MemberLinksSelfIriTemplateMapping({
    this.organization,
    this.member,
  });

  MemberLinksSelfIriTemplateMapping.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    organization = json['organization'];
    member = json['member'];
  }

  String organization;

  String member;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is MemberLinksSelfIriTemplateMapping &&
        runtimeType == other.runtimeType;
  }

  @override
  int get hashCode => 0;

  Map<String, dynamic> toJson() {
    return {
      'organization': organization,
      'member': member,
    };
  }

  @override
  String toString() {
    return 'MemberLinksSelfIriTemplateMapping[organization=$organization, member=$member, ]';
  }

  static List<MemberLinksSelfIriTemplateMapping> listFromJson(
      List<dynamic> json) {
    return json == null
        ? List<MemberLinksSelfIriTemplateMapping>()
        : json
            .map((value) => MemberLinksSelfIriTemplateMapping.fromJson(value))
            .toList();
  }

  static Map<String, MemberLinksSelfIriTemplateMapping> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, MemberLinksSelfIriTemplateMapping>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = MemberLinksSelfIriTemplateMapping.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/member_links_self_iri_template_mapping.dart <==
part of keyclic_sdk_api.api;

class MemberLinksSelfIriTemplateMapping {
  MemberLinksSelfIriTemplateMapping({
    this.member,
  });

  MemberLinksSelfIriTemplateMapping.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    member = json['member'];
  }

  String member;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is MemberLinksSelfIriTemplateMapping &&
        runtimeType == other.runtimeType &&
        member == other.member;
  }

  /// By default hashCode return reference
  @override
  int get hashCode => 0 ^ member.hashCode;

  static List<MemberLinksSelfIriTemplateMapping> listFromJson(
      List<dynamic> json) {
    return json == null
        ? <MemberLinksSelfIriTemplateMapping>[]
        : json
            .map((value) => MemberLinksSelfIriTemplateMapping.fromJson(value))
            .toList();
  }

  static Map<String, MemberLinksSelfIriTemplateMapping> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, MemberLinksSelfIriTemplateMapping>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = MemberLinksSelfIriTemplateMapping.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'member': member,
    };
  }

  @override
  String toString() {
    return 'MemberLinksSelfIriTemplateMapping[member=$member, ]';
  }
}
